@@ -54,14 +54,15 @@ has pasv                     => (is => 'rw');
 has http_header              => (is => 'rw', default => sub { {} });
 
 # repack to .tar.$zsuffix if 1
-has repack     => (is => 'rw');
-has safe       => (is => 'rw');
-has signature  => (is => 'rw');
-has symlink    => (is => 'rw');
-has timeout    => (is => 'rw');
-has user_agent => (is => 'rw');
-has uversion   => (is => 'rw');
-has watchfile  => (is => 'rw');
+has repack                  => (is => 'rw');
+has safe                    => (is => 'rw');
+has signature               => (is => 'rw');
+has symlink                 => (is => 'rw');
+has timeout                 => (is => 'rw');
+has user_agent              => (is => 'rw');
+has uversion                => (is => 'rw');
+has vcs_export_uncompressed => (is => 'rw');
+has watchfile               => (is => 'rw');
 
 # II - Options
 
@@ -110,6 +111,7 @@ use constant keys => [
     ['log', undef, 'bool'],
     ['package=s'],
     ['uversion|upstream-version=s'],
+    ['vcs-export-uncompressed', 'USCAN_VCS_EXPORT_UNCOMPRESSED', 'bool'],
     ['watchfile=s'],
     # 2.3 - More complex options
     # http headers (#955268)
@@ -193,15 +195,19 @@ use constant keys => [
         'symlink'
     ],
     # "signature" and its aliases
-    ['signature!',                   undef, 'bool', 1],
+    ['signature!', undef, 'bool', 1],
     ['skipsignature|skip-signature', undef, sub { $_[0]->signature(-1) }],
     # "verbose" and its aliases
     ['debug',       undef, sub { $verbose = 2 }],
     ['extra-debug', undef, sub { $verbose = 3 }],
     ['no-verbose',  undef, sub { $verbose = 0; return 1; }],
     [
-        'verbose|v+', 'USCAN_VERBOSE',
-        sub { $verbose = ($_[1] =~ /^(?:(\d)|yes)$/i ? $1 : 0); return 1; }
+        'verbose|v+',
+        'USCAN_VERBOSE',
+        sub {
+            $verbose = ($_[1] =~ /^yes$/i ? 1 : $_[1] =~ /^(\d)$/ ? $1 : 0);
+            return 1;
+        }
     ],
     # Display version
     [
