@@ -2,7 +2,7 @@
 # -*- tab-width: 4; indent-tabs-mode: t; cperl-indent-level: 4 -*-
 # vim: set ai shiftwidth=4 tabstop=4 expandtab:
 #   Copyright (C) Patrick Schoenfeld
-#                 2015 Johannes Schauer <josch@debian.org>
+#                 2015 Johannes Schauer Marin Rodrigues <josch@debian.org>
 #                 2017 James McCoy <jamessan@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -61,11 +61,15 @@ Select another distribution, which is searched for build-depends.
 
 =item B<--only-main>
 
-Ignore contrib and non-free
+Ignore contrib, non-free and non-free-firmware.
+
+=item B<--only-devel>
+
+Consider only development distributions (e.g. unstable, sid).
 
 =item B<--exclude-component>
 
-Ignore the given component (e.g. main, contrib, non-free).
+Ignore the given component (e.g. main, contrib, non-free, non-free-firmware).
 
 =item B<--origin>
 
@@ -102,7 +106,7 @@ dependencies, does not find transitive dependencies and does not take version
 relationships, architecture restrictions, build profiles or multiarch
 relationships into account.
 
-=item B<--quiet>
+=item B<-q>, B<--quiet>
 
 Don't print meta information (header, counter). Making it easier to use in
 scripts.
@@ -125,12 +129,12 @@ Show the version information.
 
 The tool requires apt Sources files to be around for the checked components.
 In the default case this means that in /var/lib/apt/lists files need to be
-around for main, contrib and non-free.
+around for main, contrib, non-free and non-free-firmware.
 
 In practice this means one needs to add one deb-src line for each component,
 e.g.
 
-deb-src http://<mirror>/debian <dist> main contrib non-free
+deb-src http://<mirror>/debian <dist> main contrib non-free non-free-firmware
 
 and run apt-get update afterwards or use the update option of this tool.
 
@@ -153,8 +157,9 @@ my $opt_update;
 my $opt_sudo;
 my $opt_maintainer;
 my $opt_mainonly;
+my $opt_develonly = 0;
 my $opt_distribution;
-my $opt_origin = 'Debian';
+my $opt_origin = get_current_vendor();
 my @opt_exclude_components;
 my $opt_buildarch;
 my $opt_hostarch;
@@ -190,10 +195,10 @@ Options:
    -d, --debug                    Enable the debug mode
    -m, --print-maintainer         Print the maintainer information (experimental)
    --distribution distribution    Select a distribution to search for build-depends
-                                  (Default: unstable)
    --origin origin                Select an origin to search for build-depends
                                   (Default: Debian)
-   --only-main                    Ignore contrib and non-free
+   --only-main                    Ignore contrib, non-free and non-free-firmware
+   --only-devel                   Consider only development distributions
    --exclude-component COMPONENT  Ignore the specified component (can be given multiple times)
    --host-arch                    Set the host architecture (requires dose-extra >= 4.0)
    --build-arch                   Set the build architecture (requires dose-extra >= 4.0)
@@ -205,6 +210,11 @@ EOT
     version;
 }
 
+sub debug {
+    my $msg = shift;
+    print STDERR "DEBUG: $msg\n" if $opt_debug;
+}
+
 sub test_ceve {
     return $ceve_compatible if defined $ceve_compatible;
 
@@ -212,13 +222,12 @@ sub test_ceve {
     # ceve version
     system('dose-ceve -T debsrc debsrc:///dev/null > /dev/null 2>&1');
     if ($? == -1) {
-        print STDERR "DEBUG: dose-ceve cannot be executed: $!\n"
-          if ($opt_debug);
+        debug "dose-ceve cannot be executed: $!";
         $ceve_compatible = 0;
     } elsif ($? == 0) {
         $ceve_compatible = 1;
     } else {
-        print STDERR "DEBUG: dose-ceve is too old\n" if ($opt_debug);
+        debug 'dose-ceve is too old';
         $ceve_compatible = 0;
     }
     return $ceve_compatible;
@@ -226,7 +235,7 @@ sub test_ceve {
 
 sub is_devel_release {
     my $ctrl = shift;
-    if (get_current_vendor() eq 'Debian') {
+    if ($opt_origin eq 'Debian') {
         return $ctrl->{Suite} eq 'unstable' || $ctrl->{Codename} eq 'sid';
     } else {
         return $ctrl->{Suite} eq 'devel';
@@ -249,8 +258,7 @@ sub indextargets {
         push(@cmd, 'Component: main');
     }
 
-    print STDERR 'DEBUG: Running ' . join(' ', map { "'$_'" } @cmd) . "\n"
-      if $opt_debug;
+    debug 'Running ' . join(' ', map { "'$_'" } @cmd);
     return @cmd;
 }
 
@@ -276,10 +284,16 @@ sub collect_files {
         my $ctrl = Dpkg::Control->new(type => CTRL_UNKNOWN);
         if (!$ctrl->parse($targets, 'apt-get indextargets')) {
             next;
+        } else {
+            debug "index targets stanza parsed";
+            print STDERR $ctrl if ($opt_debug);
         }
+
         # Only need Sources/Packages stanzas
         if (   $ctrl->{'Created-By'} ne 'Packages'
             && $ctrl->{'Created-By'} ne 'Sources') {
+            debug qq("Created-By: $ctrl->{'Created-By'}" )
+              . qq(not Packages/Sources\n);
             next;
         }
 
@@ -290,17 +304,29 @@ sub collect_files {
             my $invalid_component = '(?:'
               . join('|', map { "\Q$_\E" } @opt_exclude_components) . ')';
             if ($ctrl->{Component} =~ m/$invalid_component/) {
+                debug qq("Component: $ctrl->{Component}" )
+                  . qq(not $invalid_component\n);
                 next;
             }
         }
 
         # And the provided distribution
-        if ($opt_distribution) {
+        if (   !exists $ctrl->{Suite}
+            || !exists $ctrl->{Codename}) {
+            debug "no Suite or no Codename\n";
+            next;
+        } elsif ($opt_distribution) {
             if (   $ctrl->{Suite} !~ m/\Q$opt_distribution\E/
                 && $ctrl->{Codename} !~ m/\Q$opt_distribution\E/) {
+                debug qq("Suite: $ctrl->{Suite}" and )
+                  . qq("Codename: $ctrl->{Codename}" )
+                  . qq(not $opt_distribution\n);
                 next;
             }
-        } elsif (!is_devel_release($ctrl)) {
+        } elsif ($opt_develonly && !is_devel_release($ctrl)) {
+            debug qq("Suite: $ctrl->{Suite}" and )
+              . qq("Codename: $ctrl->{Codename}" )
+              . qq(not devel release\n);
             next;
         }
 
@@ -310,11 +336,15 @@ sub collect_files {
 
         if ($ctrl->{'Created-By'} eq 'Sources') {
             $ref->{sources} = $ctrl->{Filename};
-            print STDERR "DEBUG: Added source file: $ctrl->{Filename}\n"
-              if $opt_debug;
+            debug "Added source file: $ctrl->{Filename}";
         } else {
             $ref->{ $ctrl->{Architecture} } = $ctrl->{Filename};
+            debug "Added $ctrl->{Architecture} packages "
+              . "file: $ctrl->{Filename}";
         }
+
+        print STDERR "\n"
+          if $opt_debug;
     }
     close($targets);
 
@@ -348,8 +378,7 @@ sub findreversebuilddeps {
         push(@ceve_cmd, "--deb-drop-b-d-indep") if ($opt_noarchall);
         push(@ceve_cmd, "--deb-drop-b-d-arch")  if ($opt_noarchany);
         my %sources;
-        print STDERR 'DEBUG: executing: ' . join(' ', @ceve_cmd)
-          if ($opt_debug);
+        debug 'executing: ' . join(' ', @ceve_cmd);
         open(SOURCES, '-|', @ceve_cmd);
         while (<SOURCES>) {
             next unless s/^Package:\s+//;
@@ -422,6 +451,7 @@ GetOptions(
     "m|print-maintainer"  => \$opt_maintainer,
     "distribution=s"      => \$opt_distribution,
     "only-main"           => \$opt_mainonly,
+    "only-devel"          => \$opt_develonly,
     "exclude-component=s" => \@opt_exclude_components,
     "origin=s"            => \$opt_origin,
     "host-arch=s"         => \$opt_hostarch,
@@ -443,7 +473,7 @@ if (!$package) {
     die "$progname: missing argument. expecting packagename\n";
 }
 
-print STDERR "DEBUG: Package => $package\n" if ($opt_debug);
+debug "Package => $package";
 
 if ($opt_hostarch) {
     if ($opt_without_ceve) {
@@ -496,18 +526,17 @@ if ($use_ceve) {
         $opt_buildarch = `dpkg-architecture --query DEB_BUILD_ARCH`;
         chomp $opt_buildarch;
     }
-    print STDERR "DEBUG: running with dose-ceve resolver\n" if ($opt_debug);
-    print STDERR "DEBUG: buildarch=$opt_buildarch hostarch=$opt_hostarch\n"
-      if ($opt_debug);
+    debug 'running with dose-ceve resolver';
+    debug "buildarch=$opt_buildarch hostarch=$opt_hostarch";
 } else {
-    print STDERR "DEBUG: running with old resolver\n" if ($opt_debug);
+    debug 'running with old resolver';
 }
 
 if ($opt_update) {
-    print STDERR "DEBUG: Updating apt-cache before search\n" if ($opt_debug);
+    debug 'Updating apt-cache before search';
     my @cmd;
     if ($opt_sudo) {
-        print STDERR "DEBUG: Using sudo to become root\n" if ($opt_debug);
+        debug 'Using sudo to become root';
         push(@cmd, 'sudo');
     }
     push(@cmd, 'apt-get', 'update');
@@ -523,15 +552,33 @@ if (!%{$file_info}) {
 
 foreach my $site (sort keys %{$file_info}) {
     foreach my $suite (sort keys %{ $file_info->{$site} }) {
-        foreach my $comp (qw(main contrib non-free)) {
-            if (exists $file_info->{$site}{$suite}{$comp}) {
+        foreach my $comp (qw(main contrib non-free non-free-firmware)) {
+            next unless exists $file_info->{$site}{$suite}{$comp};
+            my $skipmsg = "I: skipping $site $suite $comp because";
+            if (!exists $file_info->{$site}{$suite}{$comp}->{sources}) {
                 if (!$opt_quiet) {
-                    print "Reverse Build-depends in ${comp}:\n";
-                    print "------------------------------\n\n";
+                    print STDERR "$skipmsg Sources is missing\n";
                 }
-                findreversebuilddeps($package,
-                    $file_info->{$site}{$suite}{$comp});
+                next;
             }
+            if (!exists $file_info->{$site}{$suite}{$comp}->{$opt_hostarch}) {
+                if (!$opt_quiet) {
+                    print STDERR "$skipmsg binary-$opt_hostarch is missing\n";
+                }
+                next;
+            }
+            if (!exists $file_info->{$site}{$suite}{$comp}->{$opt_buildarch}) {
+                if (!$opt_quiet) {
+                    print STDERR "$skipmsg binary-$opt_buildarch is missing\n";
+                }
+                next;
+            }
+            if (!$opt_quiet) {
+                my $msg = "Reverse Build-depends in $suite/$comp:";
+                print STDERR "$msg\n";
+                print STDERR "-" x length($msg) . "\n\n";
+            }
+            findreversebuilddeps($package, $file_info->{$site}{$suite}{$comp});
         }
     }
 }
