@@ -42,8 +42,14 @@ B<uscan> [I<options>] [I<path>]
 =head1 DESCRIPTION
 
 For basic usage, B<uscan> is executed without any arguments from the root
-of the Debianized source tree where you see the F<debian/> directory.  Then
-typically the following happens:
+of the Debianized source tree where you see the F<debian/> directory, or
+a directory containing multiple source trees.
+
+Unless --watchfile is given, B<uscan> looks recursively for valid source
+trees starting from the current directory (see the below section
+L<Directory name checking> for details).
+
+For each valid source tree found, typically the following happens:
 
 =over
 
@@ -92,7 +98,7 @@ Please note the following.
 
 =item * For simplicity, the compression method used in examples is B<gzip> with
 B<.gz> suffix.  Other methods such as B<xz>, B<bzip2>, and B<lzma> with
-corresponding B<xz>, B<bz2>, and B<lzma> suffixes may also be used.
+corresponding B<xz>, B<bz2> and B<lzma> suffixes may also be used.
 
 =item * The new B<version=4> enables handling of multiple upstream tarball
 (MUT) packages but this is a rare case for Debian packaging.  For a single
@@ -105,6 +111,10 @@ of B<uscan>'s execution.
 =item * B<uscan> with the B<--debug> option produces a human readable report of
 B<uscan>'s execution including internal variable states.
 
+=item * B<uscan> with the B<--extra-debug> option produces a human readable
+report of B<uscan>'s execution including internal variable states and remote
+content during "search" step.
+
 =item * B<uscan> with the B<--dehs> option produces an upstream package status
 report in XML format for other programs such as the Debian External Health
 System.
@@ -225,6 +235,12 @@ tarballs. (Maybe useful for MUT)
 the version obtained from F<debian/changelog>. Package version is the
 concatenation of all "group" upstream version.
 
+=item * B<checksum> requires the downloading upstream tarball to be newer than
+the version obtained from F<debian/changelog>. Package version is the
+concatenation of the version of the main tarball, followed by a checksum of all
+the tarballs using the "checksum" version system.
+At least the main upstream source has to be declared as "group".
+
 =back
 
 =item * I<script> is executed at the end of B<uscan> execution with appropriate
@@ -270,19 +286,19 @@ F<debian/changelog> file.
 
 This is substituted by the legal upstream version regex (capturing).
 
-  [-_]?(\d[\-+\.:\~\da-zA-Z]*)
+  [-_]?[Vv]?(\d[\-+\.:\~\da-zA-Z]*)
 
 =item B<@ARCHIVE_EXT@>
 
 This is substituted by the typical archive file extension regex (non-capturing).
 
-  (?i)\.(?:tar\.xz|tar\.bz2|tar\.gz|zip|tgz|tbz|txz)
+  (?i)(?:\.(?:tar\.xz|tar\.bz2|tar\.gz|tar\.zstd?|zip|tgz|tbz|txz))
 
 =item B<@SIGNATURE_EXT@>
 
 This is substituted by the typical signature file extension regex (non-capturing).
 
-  (?i)\.(?:tar\.xz|tar\.bz2|tar\.gz|zip|tgz|tbz|txz)\.(?:asc|pgp|gpg|sig|sign)
+  (?i)(?:\.(?:tar\.xz|tar\.bz2|tar\.gz|tar\.zstd?|zip|tgz|tbz|txz))'(?:\.(?:asc|pgp|gpg|sig|sign))'
 
 =item B<@DEB_EXT@>
 
@@ -314,6 +330,17 @@ The available watch options are:
 Set the name of the secondary source tarball as I<<
 <spkg>_<oversion>.orig-<component>.tar.gz >> for a MUT package.
 
+=item B<ctype=>I<component-type>
+
+Set the type of component I<(only "nodejs" and "perl" are available for now)>.
+This will help uscan to find current version if component version is ignored.
+
+When using B<ctype=nodejs>, uscan tries to find a version in C<package.json>,
+when using B<ctype=perl>, uscan tries to find a version in C<META.json>.
+If a version is found, it is used as current version for this component,
+regardless version found in Debian version string. This permits a better
+change detection when using I<ignore> or I<checksum> as Debian version.
+
 =item B<compression=>I<method>
 
 Set the compression I<method> when the tarball is repacked (persistent).
@@ -338,6 +365,8 @@ CONFIGURATION VARIABLES>.
 
 =item * The upstream archive is of B<zip> type including B<jar>, B<xpi>, ...
 
+=item * The upstream archive is of B<zstd> (Zstandard) type.
+
 =item * B<Files-Excluded> or B<Files-Excluded->I<component> stanzas are set in
 F<debian/copyright> to make B<mk-origtargz> invoked from B<uscan> remove
 files from the upstream tarball and repack it.  See L<COPYRIGHT FILE
@@ -387,7 +416,7 @@ If I<matching-pattern> is set to B<HEAD>, B<uscan> downloads source from the
 B<HEAD> of the git repository and the pertinent I<version> is automatically
 generated with the date and hash of the B<HEAD> of the git repository.
 
-If I<matching-pattern> is set to B<heads/>I<branch>, B<uscan> downloads source
+If I<matching-pattern> is set to B<refs/heads/>I<branch>, B<uscan> downloads source
 from the named I<branch> of the git repository.
 
 The local repository is temporarily created as a bare git repository directory
@@ -400,13 +429,31 @@ listed among the registered "remotes", then uscan will use it instead of cloning
 separately.  The only local change is that uscan will run a "fetch" command to
 refresh the repository.
 
+=item B<svn>
+
+This mode accesses the upstream Subversion archive directly with the B<svn>
+command and packs the source tree.
+
+For svn mode, I<matching-pattern> specifies the full string matching pattern for
+directories under Subversion repository directory, specified via URL.  The
+upstream version is extracted from concatenating the matched parts in B<(> ...
+B<)> with B<.> .
+
+If I<matching-pattern> is set to B<HEAD>, B<uscan> downloads the latest source
+tree of the URL.  The upstream version is then constructed by appending the last
+revision of the URL to B<0.0~svn>.
+
+As commit signing is not possible with Subversion, the default B<pgpmode> is set
+to B<none> when B<mode=svn>. Settings of B<pgpmode> other than B<default> and
+B<none> are reported as errors.
+
 =back
 
 =item B<pretty=>I<rule>
 
 Set the upstream version string to an arbitrary format as an optional B<opts>
 argument when the I<matching-pattern> is B<HEAD> or B<heads/>I<branch> for
-B<git> mode.  For the exact syntax, see the B<get-log> manpage under B<tformat>.
+B<git> mode.  For the exact syntax, see the B<git-log> manpage under B<tformat>.
 The default is B<pretty=0.0~git%cd.%h>.  No B<uversionmangle> rules is
 applicable for this case.
 
@@ -415,9 +462,9 @@ the "B<git describe --tags | sed s/-/./g>" command instead. For example, if the
 commit is the B<5>-th after the last tag B<v2.17.12> and its short hash is
 B<ged992511>, then the string is B<v2.17.12.5.ged992511> .  For this case, it is
 good idea to add B<uversionmangle=s/^/0.0~/> or B<uversionmangle=s/^v//> to make
-the upstream version string compatible with Debian.  B<uversionmangle=s/^v//>
-may work as well.  Please note that in order for B<pretty=describe> to function
-well, upstream need to avoid tagging with random alphabetic tags.
+the upstream version string compatible with Debian.  Please note that in order
+for B<pretty=describe> to function well, upstream need to avoid tagging with
+random alphabetic tags.
 
 The B<pretty=describe> forces to set B<gitmode=full> to make a full local clone
 of the repository automatically.
@@ -429,6 +476,15 @@ optional B<opts> argument when the I<matching-pattern> is B<HEAD> or
 B<heads/>I<branch> for B<git> mode.  For the exact syntax, see the
 B<strftime> manpage.  The default is B<date=%Y%m%d>.
 
+=item B<gitexport=>I<mode>
+
+Set the git archive export operation I<mode>. The default is
+B<gitexport=default>.  Set this to B<gitexport=all> to include all files in the
+.orig.tar archive, ignoring any I<export-ignore> git attributes defined by the
+upstream.
+
+This option is valid only in git mode.
+
 =item B<gitmode=>I<mode>
 
 Set the git clone operation I<mode>. The default is B<gitmode=shallow>.  For
@@ -500,7 +556,7 @@ HTML tags
 
 =item B<plain>: search pattern in the full page
 
-This is useful is page content is not HTML but in JSON. Example with
+This is useful if page content is not HTML but JSON. Example with
 npmjs.com:
 
   version=4
@@ -614,7 +670,7 @@ tarball URL.
 
 Generate the version string I<< <oversion> >> of the source tarball I<<
 <spkg>_<oversion>.orig.tar.gz >> from I<< <uversion> >>.  This should be used
-to add a suffix such as B<+dfsg1> to a MUT package.
+to add a suffix such as B<+dfsg> to a MUT package.
 
 =back
 
@@ -658,20 +714,20 @@ For example, if the first entry of F<debian/changelog> is:
 
 =over
 
-=item * I<< bar >> (B<3:2.03+dfsg1-4>) unstable; urgency=low
+=item * I<< bar >> (B<3:2.03+dfsg-4>) unstable; urgency=low
 
 =back
 
 then, the source package name is I<< bar >> and the last Debian package version
-is B<3:2.03+dfsg1-4>.
+is B<3:2.03+dfsg-4>.
 
-The last upstream version is normalized to B<2.03+dfsg1> by removing the epoch
+The last upstream version is normalized to B<2.03+dfsg> by removing the epoch
 and the Debian revision.
 
 If the B<dversionmangle> rule exists, the last upstream version is further
 normalized by applying this rule to it.  For example, if the last upstream
-version is B<2.03+dfsg1> indicating the source tarball is repackaged, the
-suffix B<+dfsg1> is removed by the string substitution B<s/\+dfsg\d*$//> to
+version is B<2.03+dfsg> indicating the source tarball is repackaged, the
+suffix B<+dfsg> is removed by the string substitution B<s/\+dfsg\d*$//> to
 make the (dversionmangled) last upstream version B<2.03> and it is compared to
 the candidate upstream tarball versions such as B<2.03>, B<2.04>, ... found in
 the remote site.  Thus, set this rule as:
@@ -703,11 +759,11 @@ For example, this B<http://>I<URL> may be specified as:
 
 =over
 
-=item * B<http://www.example.org/([\d\.]+)/>
+=item * B<http://www.example.org/@ANY_VERSION@/>
 
 =back
 
-Please note the trailing B</> in the above to make B<([\d\.]+)> as the
+Please note the trailing B</> in the above to make B<@ANY_VERSION@> as the
 directory.
 
 If the B<pagemangle> rule exists, the whole downloaded web page as a string is
@@ -816,7 +872,7 @@ report an error.
 
 If the B<oversionmangle> rule exists, the source tarball version I<oversion> is
 generated from the downloaded upstream version I<uversion> by applying this
-rule. This rule is useful to add suffix such as B<+dfsg1> to the version of all
+rule. This rule is useful to add suffix such as B<+dfsg> to the version of all
 the source packages of the MUT package for which the repacksuffix mechanism
 doesn't work.
 
@@ -851,16 +907,16 @@ the B<repacksuffix> option for the single upstream package.    Here I<< <oversio
 is updated to be I<< <oversion><suffix> >>.
 
 The removal of files is required if files are not DFSG-compliant.  For such
-case, B<+dfsg1> is used as I<suffix>.
+case, B<+dfsg> is used as I<suffix>.
 
 So the combined options are set as
-B<opts="dversionmangle=s/\+dfsg\d*$// ,repacksuffix=+dfsg1">, instead.
+B<opts="dversionmangle=s/\+dfsg\d*$// ,repacksuffix=+dfsg">, instead.
 
 For example, the repacked upstream tarball may be:
 
 =over
 
-=item * F<../bar_2.04+dfsg1.orig.tar.gz> (repackaged)
+=item * F<../bar_2.04+dfsg.orig.tar.gz> (repackaged)
 
 =back
 
@@ -897,14 +953,14 @@ accept such common sense abbreviations but don't push the limit.
 Here is an example for the basic single upstream tarball.
 
   version=4
-  http://example.com/~user/release/foo.html \
-      files/foo-([\d\.]+)\.tar\.gz debian uupdate
+  http://example.com/~user/release/@PACKAGE@.html \
+      files/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@
 
-Or using the special strings:
+Or without using the substitution strings (not recommended):
+  http://example.com/~user/release/foo.html \
+      files/foo-([\d\.]+)\.tar\.gz
 
   version=4
-  http://example.com/~user/release/@PACKAGE@.html \
-      files/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@ debian uupdate
 
 For the upstream source package B<foo-2.0.tar.gz>, this watch file downloads
 and creates the Debian B<orig.tar> file B<foo_2.0.orig.tar.gz>.
@@ -916,7 +972,7 @@ signature file in the same file path.
 
   version=4
   opts="pgpsigurlmangle=s%$%.asc%" http://example.com/release/@PACKAGE@.html \
-      files/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@ debian uupdate
+      files/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@
 
 For the upstream source package B<foo-2.0.tar.gz> and the upstream signature
 file B<foo-2.0.tar.gz.asc>, this watch file downloads these files, verifies the
@@ -929,7 +985,7 @@ signature file on decompressed tarball in the same file path.
   version=4
   opts="pgpsigurlmangle=s%@ARCHIVE_EXT@$%.asc%,decompress" \
       http://example.com/release/@PACKAGE@.html \
-      files/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@ debian uupdate
+      files/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@
 
 For the upstream source package B<foo-2.0.tar.gz> and the upstream signature
 file B<foo-2.0.tar.asc>, this watch file downloads these files, verifies the
@@ -945,7 +1001,7 @@ signature file in the unrelated file path.
   opts="pgpmode=next" http://example.com/release/@PACKAGE@.html \
       files/(?:\d+)/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@ debian
   opts="pgpmode=previous" http://example.com/release/@PACKAGE@.html \
-      files/(?:\d+)/@PACKAGE@@ANY_VERSION@@SIGNATURE_EXT@ previous uupdate
+      files/(?:\d+)/@PACKAGE@@ANY_VERSION@@SIGNATURE_EXT@ previous
 
 B<(?:\d+)> part can be any random value.  The tarball file can have B<53>,
 while the signature file can have B<33>.
@@ -964,7 +1020,7 @@ signature file extensions.
       files/(?:\d+)/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@ debian
   opts="pgpmode=previous" http://example.com/DL/ \
       files/(?:\d+)/@PACKAGE@@ANY_VERSION@@SIGNATURE_EXT@ \
-      previous uupdate
+      previous
 
 =head2 HTTP site (basic MUT)
 
@@ -973,13 +1029,13 @@ Here is an example for the basic multiple upstream tarballs.
   version=4
   opts="pgpsigurlmangle=s%$%.sig%" \
       http://example.com/release/foo.html \
-      files/foo-([\d\.]+)\.tar\.gz debian
+      files/foo-@ANY_VERSION@@ARCHIVE_EXT@ debian
   opts="pgpsigurlmangle=s%$%.sig%, component=bar" \
       http://example.com/release/foo.html \
-      files/foobar-([\d\.]+)\.tar\.gz same
+      files/foobar-@ANY_VERSION@@ARCHIVE_EXT@ same
   opts="pgpsigurlmangle=s%$%.sig%, component=baz" \
       http://example.com/release/foo.html \
-      files/foobaz-([\d\.]+)\.tar\.gz same uupdate
+      files/foobaz-@ANY_VERSION@@ARCHIVE_EXT@ same
 
 For the main upstream source package B<foo-2.0.tar.gz> and the secondary
 upstream source packages B<foobar-2.0.tar.gz> and B<foobaz-2.0.tar.gz> which
@@ -996,8 +1052,8 @@ after their version.
 
   version=4
   opts="pgpsigurlmangle=s%$%.sig%, dirversionmangle=s/-PRE/~pre/;s/-RC/~rc/" \
-      http://tmrc.mit.edu/mirror/twisted/Twisted/([\d+\.]+)/ \
-      Twisted-([\d\.]+)\.tar\.xz debian uupdate
+      http://tmrc.mit.edu/mirror/twisted/Twisted/@ANY_VERSION@/ \
+      Twisted-@ANY_VERSION@@ARCHIVE_EXT@
 
 Here, the web site should be accessible at the following URL:
 
@@ -1014,16 +1070,14 @@ watch file:
   version=4
   opts="pgpsigurlmangle=s%$%.sig%" \
       http://www.cpan.org/modules/by-module/Text/ \
-      Text-CSV_XS-(.+)\.tar\.gz \
-      debian uupdate
+      Text-CSV_XS-@ANY_VERSION@@ARCHIVE_EXT@
 
 can be rewritten in an alternative shorthand form only with a single string
 covering URL and filename:
 
   version=4
   opts="pgpsigurlmangle=s%$%.sig%" \
-      http://www.cpan.org/modules/by-module/Text/Text-CSV_XS-(.+)\.tar\.gz \
-      debian uupdate
+      http://www.cpan.org/modules/by-module/Text/Text-CSV_XS-@ANY_VERSION@@ARCHIVE_EXT@
 
 In version=4, initial white spaces are dropped.  Thus, this alternative
 shorthand form can also be written as:
@@ -1031,8 +1085,7 @@ shorthand form can also be written as:
   version=4
   opts="pgpsigurlmangle=s%$%.sig%" \
       http://www.cpan.org/modules/by-module/Text/\
-      Text-CSV_XS-(.+)\.tar\.gz \
-      debian uupdate
+      Text-CSV_XS-@ANY_VERSION@@ARCHIVE_EXT@
 
 Please note the subtle difference of a space before the tailing B<\>
 between the first and the last examples.
@@ -1043,8 +1096,7 @@ For a site which has funny version numbers, the parenthesized groups will be
 joined with B<.> (period) to make a sanitized version number.
 
   version=4
-  http://www.site.com/pub/foobar/foobar_v(\d+)_(\d+)\.tar\.gz \
-  debian uupdate
+  http://www.site.com/pub/foobar/foobar_v(\d+)_(\d+)@ARCHIVE_EXT@
 
 =head2 HTTP site (DFSG)
 
@@ -1052,8 +1104,8 @@ The upstream part of the Debian version number can be mangled to indicate the
 source package was repackaged to clean up non-DFSG files:
 
   version=4
-  opts="dversionmangle=s/\+dfsg\d*$//,repacksuffix=+dfsg1" \
-  http://some.site.org/some/path/foobar-(.+)\.tar\.gz debian uupdate
+  opts="dversionmangle=s/\+dfsg\d*$//,repacksuffix=+dfsg" \
+  http://some.site.org/some/path/foobar-@ANY_VERSION@@ARCHIVE_EXT@
 
 See L<COPYRIGHT FILE EXAMPLES>.
 
@@ -1068,25 +1120,21 @@ as:
 
   version=4
   opts=filenamemangle=s/.*=(.*)/$1/ \
-  http://foo.bar.org/dl/\?path=&dl=foo-(.+)\.tar\.gz \
-  debian uupdate
+  http://foo.bar.org/dl/\?path=&dl=foo-@ANY_VERSION@@ARCHIVE_EXT@
 
 F<< <A href="http://foo.bar.org/dl/?path=&dl_version=0.1.1"> >>
 could be handled as:
 
   version=4
   opts=filenamemangle=s/.*=(.*)/foo-$1\.tar\.gz/ \
-  http://foo.bar.org/dl/\?path=&dl_version=(.+) \
-  debian uupdate
+  http://foo.bar.org/dl/\?path=&dl_version=@ANY_VERSION@
 
 If the href string has no version using <I>matching-pattern>, the version can
 be obtained from the full URL using B<filenamemangle>.
 
   version=4
   opts=filenamemangle=s&.*/dl/(.*)/foo\.tar\.gz&foo-$1\.tar\.gz& \
-  http://foo.bar.org/dl/([\.\d]+)/ foo.tar.gz \
-  debian uupdate
-
+  http://foo.bar.org/dl/@ANY_VERSION@/ foo.tar.gz
 
 =head2 HTTP site (downloadurlmangle)
 
@@ -1098,22 +1146,21 @@ some way into one which will work automatically, for example:
   version=4
   opts=downloadurlmangle=s/prdownload/download/ \
   http://developer.berlios.de/project/showfiles.php?group_id=2051 \
-  http://prdownload.berlios.de/softdevice/vdr-softdevice-(.+).tgz \
-  debian uupdate
+  http://prdownload.berlios.de/softdevice/vdr-softdevice-@ANY_VERSION@@ARCHIVE_EXT@
 
 =head2 HTTP site (oversionmangle, MUT)
 
 The option B<oversionmangle> can be used to mangle the version of the source
-tarball (B<.orig.tar.gz> and B<.orig-bar.tar.gz>).  For example, B<+dfsg1> can
+tarball (B<.orig.tar.gz> and B<.orig-bar.tar.gz>).  For example, B<+dfsg> can
 be added to the upstream version as:
 
   version=4
-  opts=oversionmangle=s/(.*)/$1+dfsg1/ \
+  opts=oversionmangle=s/(.*)/$1+dfsg/ \
   http://example.com/~user/release/foo.html \
-  files/foo-([\d\.]*).tar.gz debian
+  files/foo-@ANY_VERSION@@ARCHIVE_EXT@ debian
   opts="component=bar" \
   http://example.com/~user/release/foo.html \
-  files/bar-([\d\.]*).tar.gz same uupdate
+  files/bar-@ANY_VERSION@@ARCHIVE_EXT@ same
 
 See L<COPYRIGHT FILE EXAMPLES>.
 
@@ -1128,7 +1175,7 @@ standard page format with:
   version=4
   opts=pagemangle="s/<a\s+bogus=/<a href=/g" \
   http://example.com/release/foo.html \
-  files/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@ debian uupdate
+  files/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@
 
 Please note the use of B<g> here to replace all occurrences.
 
@@ -1138,19 +1185,18 @@ converted to the standard page format with:
   version=4
   opts="pagemangle=s%<Key>([^<]*)</Key>%<Key><a href="$1">$1</a></Key>%g" \
   http://example.com/release/foo.html \
-  (?:.*)/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@ debian uupdate
+  (?:.*)/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@
 
 =head2 FTP site (basic):
 
   version=4
-  ftp://ftp.tex.ac.uk/tex-archive/web/c_cpp/cweb/cweb-(.+)\.tar\.gz \
-  debian uupdate
+  ftp://ftp.tex.ac.uk/tex-archive/web/c_cpp/cweb/cweb-@ANY_VERSION@@ARCHIVE_EXT@
 
 =head2 FTP site (regex special characters):
 
   version=4
   ftp://ftp.worldforge.org/pub/worldforge/libs/\
-  Atlas-C++/transitional/Atlas-C\+\+-(.+)\.tar\.gz debian uupdate
+  Atlas-C++/transitional/Atlas-C\+\+-@ANY_VERSION@@ARCHIVE_EXT@
 
 Please note that this URL is connected to be I< ... >B<libs/Atlas-C++/>I< ... >
 . For B<++>, the first one in the directory path is verbatim while the one in
@@ -1167,7 +1213,7 @@ version numbers.)
   version=4
   opts="uversionmangle=s/^/0.0./" \
   ftp://ftp.ibiblio.org/pub/Linux/ALPHA/wine/\
-  development/Wine-(.+)\.tar\.gz debian uupdate
+  development/Wine-@ANY_VERSION@@ARCHIVE_EXT@
 
 =head2 sf.net
 
@@ -1176,36 +1222,86 @@ simpler form of URL. The format below will automatically be rewritten to use
 the redirector with the watch file:
 
   version=4
-  https://sf.net/<project>/ <tar-name>-(.+)\.tar\.gz debian uupdate
+  https://sf.net/<project>/ <tar-name>-@ANY_VERSION@@ARCHIVE_EXT@
 
 For B<audacity>, set the watch file as:
 
   version=4
-  https://sf.net/audacity/ audacity-minsrc-(.+)\.tar\.gz debian uupdate
+  https://sf.net/audacity/ audacity-minsrc-@ANY_VERSION@@ARCHIVE_EXT@
 
 Please note, you can still use normal functionalities of B<uscan> to set up a
 watch file for this site without using the redirector.
 
   version=4
   opts="uversionmangle=s/-pre/~pre/, \
-	filenamemangle=s%(?:.*)audacity-minsrc-(.+)\.tar\.xz/download%\
+    filenamemangle=s%(?:.*)audacity-minsrc-(.+)\.tar\.xz/download%\
                          audacity-$1.tar.xz%" \
-	http://sourceforge.net/projects/audacity/files/audacity/(\d[\d\.]+)/ \
-	(?:.*)audacity-minsrc-([\d\.]+)\.tar\.xz/download debian uupdate
+    http://sourceforge.net/projects/audacity/files/audacity/@ANY_VERSION@/ \
+    (?:.*)audacity-minsrc-@ANY_VERSION@@ARCHIVE_EXT@/download
 
 Here, B<%> is used as the separator instead of the standard B</>.
 
 =head2 github.com
 
-For GitHub based projects, you can use the tags or releases page.  The archive
-URL uses only the version as the filename.  You can rename the downloaded
-upstream tarball from into the standard F<< <project>-<version>.tar.gz >> using
-B<filenamemangle>:
+For GitHub based projects, you can use the releases or tags API page.  If
+upstream releases properly named tarballs on their releases page, you can
+search for the browser download URL (API key F<browser_download_url>):
 
   version=4
-  opts="filenamemangle=s%(?:.*?)?v?(\d[\d.]*)\.tar\.gz%<project>-$1.tar.gz%" \
-      https://github.com/<user>/<project>/tags \
-      (?:.*?/)?v?(\d[\d.]*)\.tar\.gz debian uupdate
+  opts=\
+  filenamemangle=s%.*/@ANY_VERSION@%@PACKAGE@-$1.tar.gz%,\
+  downloadurlmangle=s%(api.github.com/repos/[^/]+/[^/]+)/git/refs/%$1/tarball/refs/%g,\
+  searchmode=plain \
+   https://api.github.com/repos/<user>/<project>/git/matching-refs/tags/ \
+   https://api.github.com/repos/[^/]+/[^/]+/git/refs/tags/@ANY_VERSION@
+
+It is also possible to filter tags by prefix. For example to get only tags
+starting by C<v1>:
+
+  version=4
+  opts=\
+  filenamemangle=s%.*/@ANY_VERSION@%@PACKAGE@-$1.tar.gz%,\
+  downloadurlmangle=s%(api.github.com/repos/[^/]+/[^/]+)/git/refs/%$1/tarball/refs/%g,\
+  searchmode=plain \
+   https://api.github.com/repos/<user>/<project>/git/matching-refs/tags/v1 \
+   https://api.github.com/repos/[^/]+/[^/]+/git/refs/tags/@ANY_VERSION@
+
+Alternatives with releases only (if upstream does not delete tag after release):
+
+  version=4
+  opts=\
+  filenamemangle=s%.*/@ANY_VERSION@%@PACKAGE@-$1.tar.gz%,\
+  downloadurlmangle=s%api.github.com/repos/([^/]+/[^/]+)/git/refs/tags/@ANY_VERSION@%github.com/$1/archive/refs/tags/$2.tar.gz%g,\
+  searchmode=plain \
+   https://api.github.com/repos/<user>/<project>/git/matching-refs/tags/ \
+   https://api.github.com/repos/[^/]+/[^/]+/git/refs/tags/@ANY_VERSION@
+
+In case of release that does not use tags or deleted tags:
+
+  version=4
+  opts="filenamemangle=s%.*/@ANY_VERSION@%@PACKAGE@-$1.tar.gz%,searchmode=plain" \
+      https://api.github.com/repos/<user>/<project>/releases?per_page=100 \
+      https://api.github.com/repos/<user>/<project>/tarball/@ANY_VERSION@
+
+If upstream releases alpha/beta tarballs, you will need to make use of the
+B<uversionmangle> option: F<uversionmangle=s/(a|alpha|b|beta|c|dev|pre|rc)/~$1/>
+
+If upstream forget to tag a release for instance here the C<1.2.3> version corresponding
+to commit C<0123456789abcdf01234567890abcef012345678>, you could download it,
+using the following combinaison of B<oversionmangle>, B<filenamemangle>,
+B<downloadurlmangle> options:
+
+  version=4
+  opts=\
+  downloadurlmangle=s%(api.github.com/repos/[^/]+/[^/]+)/git/refs/.*%$1/tarball/0123456789abcdf01234567890abcef012345678%g,\
+  oversionmangle=s/.*/1.2.3~git/g,\
+  filenamemangle=s%.*%1.2.3~git.tar.gz%,\
+  searchmode=plain \
+   https://api.github.com/repos/ImageMagick/ImageMagick/git/matching-refs/tags/ \
+   https://api.github.com/repos/[^/]+/[^/]+/git/refs/tags/@ANY_VERSION@
+
+Remember, in this case, after B<gbp> B<import-orig> B<--uscan> to revert
+the F<debian/watch> file.
 
 =head2 PyPI
 
@@ -1215,13 +1311,13 @@ the redirector with the watch file:
 
   version=4
   https://pypi.python.org/packages/source/<initial>/<project>/ \
-      <tar-name>-(.+)\.tar\.gz debian uupdate
+      <tar-name>-@ANY_VERSION@@ARCHIVE_EXT@
 
 For B<cfn-sphere>, set the watch file as:
 
   version=4
   https://pypi.python.org/packages/source/c/cfn-sphere/ \
-      cfn-sphere-([\d\.]+).tar.gz debian uupdate
+      cfn-sphere-@ANY_VERSION@@ARCHIVE_EXT@
 
 Please note, you can still use normal functionalities of B<uscan> to set up a
 watch file for this site without using the redirector.
@@ -1230,7 +1326,7 @@ watch file for this site without using the redirector.
   opts="pgpmode=none" \
       https://pypi.python.org/pypi/cfn-sphere/ \
       https://pypi.python.org/packages/.*/.*/.*/\
-      cfn-sphere-([\d\.]+).tar.gz#.* debian uupdate
+      cfn-sphere-@ANY_VERSION@@ARCHIVE_EXT@#.*
 
 =head2 code.google.com
 
@@ -1244,7 +1340,7 @@ npmjs.org modules are published in JSON files. Here is a way to read them:
   version=4
   opts="searchmode=plain" \
    https://registry.npmjs.org/aes-js \
-   https://registry.npmjs.org/aes-js/-/aes-js-(\d[\d\.]*)@ARCHIVE_EXT@
+   https://registry.npmjs.org/aes-js/-/aes-js-@ANY_VERSION@@ARCHIVE_EXT@
 
 =head2 grouped package
 
@@ -1254,20 +1350,60 @@ a way to group them:
   version=4
   opts="searchmode=plain,pgpmode=none" \
     https://registry.npmjs.org/mongodb \
-    https://registry.npmjs.org/mongodb/-/mongodb-(\d[\d\.]*)@ARCHIVE_EXT@ group
+    https://registry.npmjs.org/mongodb/-/mongodb-@ANY_VERSION@@ARCHIVE_EXT@ group
   opts="searchmode=plain,pgpmode=none,component=bson" \
     https://registry.npmjs.org/bson \
-    https://registry.npmjs.org/bson/-/bson-(\d[\d\.]*)@ARCHIVE_EXT@ group
+    https://registry.npmjs.org/bson/-/bson-@ANY_VERSION@@ARCHIVE_EXT@ group
   opts="searchmode=plain,pgpmode=none,component=mongodb-core" \
     https://registry.npmjs.org/mongodb-core \
-    https://registry.npmjs.org/mongodb-core/-/mongodb-core-(\d[\d\.]*)@ARCHIVE_EXT@ group
+    https://registry.npmjs.org/mongodb-core/-/mongodb-core-@ANY_VERSION@@ARCHIVE_EXT@ group
   opts="searchmode=plain,pgpmode=none,component=requireoptional" \
     https://registry.npmjs.org/require_optional \
-    https://registry.npmjs.org/require_optional/-/require_optional-(\d[\d\.]*)@ARCHIVE_EXT@ group
+    https://registry.npmjs.org/require_optional/-/require_optional-@ANY_VERSION@@ARCHIVE_EXT@ group
 
 Package version is then the concatenation of upstream versions separated by
 "+~".
 
+To avoid having a too long version, the "checksum" method can be used.
+In this case, the main source has to be declared as "group":
+
+  version=4
+  opts="searchmode=plain,pgpmode=none" \
+    https://registry.npmjs.org/mongodb \
+    https://registry.npmjs.org/mongodb/-/mongodb-@ANY_VERSION@@ARCHIVE_EXT@ group
+  opts="searchmode=plain,pgpmode=none,component=bson" \
+    https://registry.npmjs.org/bson \
+    https://registry.npmjs.org/bson/-/bson-@ANY_VERSION@@ARCHIVE_EXT@ checksum
+  opts="searchmode=plain,pgpmode=none,component=mongodb-core" \
+    https://registry.npmjs.org/mongodb-core \
+    https://registry.npmjs.org/mongodb-core/-/mongodb-core-@ANY_VERSION@@ARCHIVE_EXT@ checksum
+  opts="searchmode=plain,pgpmode=none,component=requireoptional" \
+    https://registry.npmjs.org/require_optional \
+    https://registry.npmjs.org/require_optional/-/require_optional-@ANY_VERSION@@ARCHIVE_EXT@ checksum
+
+The "checksum" is made up of the separate sum of each number composing the
+component versions.  Following is an example with 3 components whose versions
+are "1.2.4", "2.0.1" and "10.0", with the main tarball having version "2.0.6":
+
+  Main: 2.0.6
+  Comp1:         1 .     2 .     4
+  Comp2:         2 .     0 .     1
+  Comp3:        10 .     0
+  ================================
+  Result  : 1+2+10 . 2+0+0 .   4+1
+  Checksum:     13 .     2 .     5
+  ================================
+  Final Version:   2.0.6+~cs13.2.5
+
+uscan will also display the original version string before being encoded into
+the checksum, which can for example be used in a debian/changelog entry to
+easily follow the changes:
+
+  2.0.6+~1.2.4+~2.0.1+~10.0
+
+B<Note>: This feature currently accepts only versions composed of digits and
+full stops (`.`).
+
 =head2 direct access to the git repository (tags)
 
 If the upstream only publishes its code via the git repository and its code has
@@ -1277,7 +1413,7 @@ tags of the git repository to track and package the new upstream release.
   version=4
   opts="mode=git, gitmode=full, pgpmode=none" \
   http://git.ao2.it/tweeper.git \
-  refs/tags/v([\d\.]+) debian uupdate
+  refs/tags/v@ANY_VERSION@
 
 Please note "B<git ls-remote>" is used to obtain references for tags.
 
@@ -1297,7 +1433,7 @@ upstream release with an automatically generated version string.
   version=4
   opts="mode=git, pgpmode=none" \
   https://github.com/Debian/dh-make-golang \
-  HEAD debian uupdate
+  HEAD
 
 Please note that a local shallow copy of the git repository is made with "B<git
 clone --bare --depth=1> ..." normally in the target directory.  B<uscan>
@@ -1308,6 +1444,45 @@ behavior.
 The generation of the upstream version string may the adjusted to your taste by
 adding B<pretty> and B<date> options to the B<opts> arguments.
 
+=head2 direct access to the Subversion repository (tags)
+
+If the upstream only publishes its code via the Subversion repository and its
+code has no web interface to obtain the release tarball, you can use B<uscan>
+with the tags of the Subversion repository to track and package the new upstream
+release.
+
+  version=4
+  opts="mode=svn, pgpmode=none" \
+  svn://svn.code.sf.net/p/jmol/code/tags/ \
+  @ANY_VERSION@\/
+
+=head2 direct access to the Subversion repository (HEAD)
+
+If the upstream only publishes its code via the Subversion repository and its
+code has no web interface to obtain the release tarball, you can use B<uscan>
+to get the most recent source of a subtree in the repository with an
+automatically generated version string.
+
+  version=4
+  opts="mode=svn, pgpmode=none" \
+  svn://svn.code.sf.net/p/jmol/code/trunk/ \
+  HEAD
+
+By default, B<uscan> generates the new upstream version by appending the
+revision number to "0.0~svn". This can later be changed using B<uversionmangle>.
+
+=head2 Fossil
+
+For Fossil based projects, the tarball URL can be deduced from the taglist page.
+
+  version=4
+  opts=" \
+    searchmode=plain, \
+    filenamemangle=s/timeline\?t=(@ANY_VERSION@)/@PACKAGE@-$1.tar.gz/, \
+    downloadurlmangle=s#/timeline\?t=(@ANY_VERSION@)#/tarball/Grammalecte.tar.gz?r=$1#" \
+    http://grammalecte.net:8080/taglist \
+    /timeline\?t=@ANY_VERSION@
+
 =head1 COPYRIGHT FILE EXAMPLES
 
 Here is an example for the F<debian/copyright> file which initiates automatic
@@ -1457,6 +1632,10 @@ Report verbose information.
 
 =item B<--debug>, B<-vv>
 
+Report verbose information and some internal state values.
+
+=item B<--extra-debug>, B<-vvv>
+
 Report verbose information including the downloaded
 web pages as processed to STDERR for debugging.
 
@@ -1553,7 +1732,7 @@ directory of B<uscan> execution. If this I<path> is a absolute path, the
 destination directory is set to I<path> irrespective of the internal current
 directory of B<uscan> execution.
 
-The above is true not only for the sinple B<uscan> run in the single source tree
+The above is true not only for the simple B<uscan> run in the single source tree
 but also for the advanced scanning B<uscan> run with subdirectories holding
 multiple source trees.
 
@@ -1578,6 +1757,13 @@ Specify the current upstream version rather than examine F<debian/watch> or
 F<debian/changelog> to determine it. This is ignored if a directory scan is being
 performed and more than one F<debian/watch> file is found.
 
+=item B<--vcs-export-uncompressed>
+
+Disable compression of tarballs exported from a version control system
+(Git or Subversion). This takes more space, but saves time if
+B<mk-origtargz> must repack the tarball to exclude files. It forces
+repacking of all exported tarballs.
+
 =item B<--watchfile> I<watchfile>
 
 Specify the I<watchfile> rather than perform a directory scan to determine it.
@@ -1597,6 +1783,36 @@ See more in the B<--destdir> explanation.
 Disable all site specific special case codes to perform URL redirections and
 page content alterations.
 
+=item B<--http-header>
+
+Add specified header in HTTP requests for matching url. This option can be used
+more than one time, values must be in the form "baseUrl@Name=value. Example:
+
+  uscan --http-header https://example.org@My-Token=qwertyuiop
+
+Security:
+
+=over
+
+=item The given I<baseUrl> must exactly match the base url before '/'.
+Examples:
+
+  |        --http-header value         |           Good for          | Never used |
+  +------------------------------------+-----------------------------+------------+
+  | https://example.org.com@Hdr=Value  | https://example.org.com/... |            |
+  | https://example.org.com/@Hdr=Value |                             |     X      |
+  | https://e.com:1879@Hdr=Value       | https://e.com:1879/...      |            |
+  | https://e.com:1879/dir@Hdr=Value   | https://e.com:1879/dir/...  |            |
+  | https://e.com:1879/dir/@Hdr=Value  |                             |     X      |
+
+=item It is strongly recommended to not use this feature to pass a secret
+token over unciphered connection I<(http://)>
+
+=item You can use C<USCAN_HTTP_HEADER> variable (in C<~/.devscripts>) to hide
+secret token from scripts
+
+=back
+
 =item B<--no-exclusion>
 
 Don't automatically exclude files mentioned in F<debian/copyright> field B<Files-Excluded>.
@@ -1650,12 +1866,12 @@ Instead of symlinking as described above, rename the downloaded files.
 
 =item B<--repack>
 
-After having downloaded an lzma tar, xz tar, bzip tar, gz tar, zip, jar, xpi
-archive, repack it to the specified compression (see B<--compression>).
+After having downloaded an lzma tar, xz tar, bzip tar, gz tar, zip, jar, xpi,
+zstd archive, repack it to the specified compression (see B<--compression>).
 
-The unzip package must be installed in order to repack zip and jar archives,
-the mozilla-devscripts package must be installed to repack xpi archives, and
-the xz-utils package must be installed to repack lzma or xz tar archives.
+The unzip package must be installed in order to repack zip, jar, and xpi
+archives, the xz-utils package must be installed to repack lzma or xz tar
+archives, and zstd must be installed to repack zstd archives.
 
 =item B<--compression> [ B<gzip> | B<bzip2> | B<lzma> | B<xz> ]
 
@@ -1750,8 +1966,8 @@ equivalent to the B<--destdir> option.
 =item B<USCAN_REPACK>
 
 If this is set to yes, then after having downloaded a bzip tar, lzma tar, xz
-tar, or zip archive, uscan will repack it to the specified compression (see
-B<--compression>). This is equivalent to the B<--repack> option.
+tar, zip or zstd archive, uscan will repack it to the specified compression
+(see B<--compression>). This is equivalent to the B<--repack> option.
 
 =item B<USCAN_EXCLUSION>
 
@@ -1759,6 +1975,17 @@ If this is set to no, files mentioned in the field B<Files-Excluded> of
 F<debian/copyright> will be ignored and no exclusion of files will be tried.
 This is equivalent to the B<--no-exclusion> option.
 
+=item B<USCAN_HTTP_HEADER>
+
+If set, the specified http header will be used if URL match. This is equivalent
+to B<--http-header> option.
+
+=item B<USCAN_VCS_EXPORT_UNCOMPRESSED>
+
+If this is set to yes, tarballs exported from a version control system
+will not be compressed. This is equivalent to the
+B<--vcs-export-uncompressed> option.
+
 =back
 
 =head1 EXIT STATUS
@@ -1785,10 +2012,6 @@ No newer upstream versions were located for any of the F<watch> files examined.
 B<uscan> has many other enhanced features which are skipped in the above
 section for the simplicity.  Let's check their highlights.
 
-B<uscan> actually scans not just the current directory but all its
-subdirectories looking for F<debian/watch> to process them all.
-See L<Directory name checking>.
-
 B<uscan> can be executed with I<path> as its argument to change the starting
 directory of search from the current directory to I<path> .
 
@@ -1891,7 +2114,8 @@ this manpage and to start from scratch.
 =item Version 2
 
 B<devscripts> version 2.6.90: The first incarnation of the current style of
-F<watch> files.
+F<watch> files. This version is also deprecated and will be rejected after
+the Debian 11 release.
 
 =item Version 3
 
@@ -2010,7 +2234,8 @@ my $res = 0;
 
 my @wf = find_watch_files($config);
 foreach (@wf) {
-    $res ||= process_watchfile(@$_);
+    my $tmp = process_watchfile(@$_);
+    $res ||= $tmp;
 
     # Are there any warnings to give if we're using dehs?
     dehs_output if ($dehs);
@@ -2049,4 +2274,3 @@ sub process_watchfile {
 #######################################################################
 # }}} code 2: process watchfile by looping over watchline
 #######################################################################
-
